@@ -1,5 +1,3 @@
-import React from 'react';
-
 import EmptyListCTA from 'app/core/components/EmptyListCTA/EmptyListCTA';
 import { contextSrv } from 'app/core/core';
 
@@ -9,7 +7,11 @@ import { Props } from './DataSourceCache';
 
 export const CacheCTA = (props: Props) => {
   const { enableDataSourceCache, dataSource, pageId } = props;
-  const canWriteCache = contextSrv.hasPermissionInMetadata(AccessControlAction.DataSourcesCachingWrite, dataSource);
+  const canWriteCache = 
+    contextSrv.hasPermissionInMetadata(
+      AccessControlAction.DataSourcesCachingWrite,
+      dataSource
+    ) && dataSource.readOnly === false;
 
   return dataSource.jsonData?.disableGrafanaCache ? (
     <EmptyListCTA
